use winit::{dpi::PhysicalSize, event::{Touch, TouchPhase, WindowEvent}};
use crate::graphics::Vertex;

const SECONDARY_COLOR: [f32; 4] = [84./255., 33./255., 32./255., 1.];
const KIND_BUTTON_SIZE: f32 = 0.2;

#[derive(Debug, Clone, Copy, PartialEq, Eq)]
pub enum Kind {
    None,
    Terrain,
    Entities
}

pub struct UI {
    pub kind_selected: Kind
}
impl UI {
    pub fn new() -> Self {
        Self {
            kind_selected: Kind::Entities
        }
    }
    pub fn render(&self, vertices: &mut Vec<Vertex>, indices: &mut Vec<u32>, screen_size: PhysicalSize<u32>) {
        let ratio = screen_size.height as f32/screen_size.width as f32;
        let vs = [
            // Terrain
            Vertex::new_tex([-1. + (0.02*ratio), -1. + (0.02+KIND_BUTTON_SIZE)], [0, 1], 0),
            Vertex::new_tex([-1. + (0.02*ratio), -1. + 0.02], [0, 13], 0),
            Vertex::new_tex([-1. + ((0.02+KIND_BUTTON_SIZE)*ratio), -1. + 0.02], [12, 13], 0),
            Vertex::new_tex([-1. + ((0.02+KIND_BUTTON_SIZE)*ratio), -1. + (0.02+KIND_BUTTON_SIZE)], [12, 1], 0),

            // Entities
            Vertex::new_tex([-1. + ((0.02+KIND_BUTTON_SIZE)*ratio)+(0.02*ratio), -1. + (0.02+KIND_BUTTON_SIZE)], [12, 1], 0),
            Vertex::new_tex([-1. + ((0.02+KIND_BUTTON_SIZE)*ratio)+(0.02*ratio), -1. + 0.02], [12, 13], 0),
            Vertex::new_tex([-1. + ((0.02+KIND_BUTTON_SIZE)*ratio)+((0.02+KIND_BUTTON_SIZE)*ratio), -1. + 0.02], [24, 13], 0),
            Vertex::new_tex([-1. + ((0.02+KIND_BUTTON_SIZE)*ratio)+((0.02+KIND_BUTTON_SIZE)*ratio), -1. + (0.02+KIND_BUTTON_SIZE)], [24, 1], 0),
        ];
        let ids = [
            0,1,2,
            2,3,0,
            4,5,6,
            6,7,4
        ];
        let i = vertices.len() as u32;
        vertices.extend_from_slice(&vs);
        indices.extend_from_slice(&ids.map(|id| id+i));
    }
}
